@@ -1,5 +1,7 @@
+use crate::version_file_strategy::VersionFileStrategy;
+
 use super::shell::Shell;
-use indoc::indoc;
+use indoc::{formatdoc, indoc};
 use std::path::Path;
 
 #[derive(Debug)]
@@ -18,19 +20,27 @@ impl Shell for Fish {
         format!("set -gx {name} {value:?};", name = name, value = value)
     }
 
-    fn use_on_cd(&self, _config: &crate::config::FnmConfig) -> String {
-        indoc!(
+    fn use_on_cd(&self, config: &crate::config::FnmConfig) -> String {
+        let autoload_hook = match config.version_file_strategy() {
+            VersionFileStrategy::Local => indoc!(
+                r#"
+                    if test -f .node-version -o -f .nvmrc
+                        fnm use --silent-if-unchanged
+                    end
+                "#
+            ),
+            VersionFileStrategy::Recursive => r#"fnm use --silent-if-unchanged"#,
+        };
+        formatdoc!(
             r#"
                 function _fnm_autoload_hook --on-variable PWD --description 'Change Node version on directory change'
                     status --is-command-substitution; and return
-                    if test -f .node-version -o -f .nvmrc
-                        fnm use
-                    end
+                    {autoload_hook}
                 end
 
                 _fnm_autoload_hook
-            "#
+            "#,
+            autoload_hook = autoload_hook
         )
-        .into()
     }
 }
